@@ -34,10 +34,10 @@ def authenticate_hawk_header(
     if not matching_credentials:
         return 'Unidentified id', None
 
-    canonical_payload = \
-        b'hawk.1.payload' + b'\n' + \
-        content_type.encode('utf-8') + b'\n' + \
-        content + b'\n'
+    canonical_payload = (
+        f'hawk.1.payload\n{content_type}\n'.encode('ascii'),
+        content, b'\n',
+    )
     payload_hash = _base64_digest(canonical_payload)
 
     canonical_request = \
@@ -45,7 +45,7 @@ def authenticate_hawk_header(
         f'\n{method}\n{path}\n{host}\n{port}\n' \
         f'{payload_hash}\n\n'
     correct_mac = _base64_mac(
-        matching_credentials['key'].encode('utf-8'), canonical_request.encode('utf-8'))
+        matching_credentials['key'].encode('ascii'), canonical_request.encode('ascii'))
 
     if not hmac.compare_digest(payload_hash, parsed_header['hash']):
         return 'Invalid hash', None
@@ -62,9 +62,12 @@ def authenticate_hawk_header(
     return None, matching_credentials
 
 
-def _base64_digest(data):
-    return b64encode(hashlib.sha256(data).digest()).decode('utf-8')
+def _base64_digest(chunks):
+    m = hashlib.sha256()
+    for chunk in chunks:
+        m.update(chunk)
+    return b64encode(m.digest()).decode('ascii')
 
 
 def _base64_mac(key, data):
-    return b64encode(hmac.new(key, data, hashlib.sha256).digest()).decode('utf-8')
+    return b64encode(hmac.new(key, data, hashlib.sha256).digest()).decode('ascii')
